@@ -1,6 +1,6 @@
 package Web::PerlDistSite::Component::LayoutScss;
 
-our $VERSION = '0.001004';
+our $VERSION = '0.001005';
 
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
@@ -33,16 +33,6 @@ body {
 	}
 }
 
-html, body {
-	scroll-snap-type: y proximity;
-}
-header, .has-sections > section {
-	scroll-snap-align: start;
-}
-footer {
-	scroll-snap-align: end;
-}
-
 header {
 	@extend .sticky-top;
 	@extend .bg-primary;
@@ -69,6 +59,11 @@ header {
 	}
 }
 
+#main {
+	height: 1px;
+	width: 1px;
+}
+
 .homepage-hero {
 	@extend .bg-primary;
 	position: relative;
@@ -100,34 +95,39 @@ header {
 		}
 	}
 	
-	.homepage-hero-button {
-		@extend .text-white;
-		@extend .text-center;
-		position: absolute;
-		bottom: 18vh;
-		width: 100%;
-		font-size: 2rem;
-		
-		a:link, a:visited {
-			@extend .text-white;
-			text-decoration: underline;
-			position: relative;
-			i {
-				position: absolute;
-				top: 0;
-				left: -0.67rem;
-				animation: bounce 1s infinite alternate;
-			}
-		}
-	}
-	
 	.homepage-hero-graphic {
 		width: 100%;
 		height: 95vh;
 		height: calc(100vh - 56px);
+		height: calc(100dvh - 56px);
 	}
 }
 
+.homepage-hero-button {
+	@extend .text-white;
+	@extend .text-center;
+	position: absolute;
+	bottom: 18vh;
+	width: 100%;
+	font-size: 2rem;
+	
+	a:link, a:visited {
+		@extend .text-white;
+		text-decoration: underline;
+		position: relative;
+		i {
+			position: absolute;
+			top: 0;
+			left: -0.67rem;
+			animation: bounce 1.2s infinite alternate;
+		}
+	}
+}
+
+@keyframes bounce {
+	to { transform: scale(1.2); }
+}
+
 .homepage-hero-banner {
 	width: 100%;
 	height: 95vh;
@@ -138,15 +138,6 @@ header {
 	}
 }
 
-@keyframes bounce {
-	to { transform: scale(1.2); }
-}
-
-div#down {
-	height: 1px;
-	width: 1px;
-}
-
 body.page main {
 	@extend .my-4;
 }
@@ -185,3 +176,29 @@ footer {
 		@extend .text-light;
 	}
 }
+
+#return-to-top {
+	@extend .text-secondary;
+	font-size: 2rem;
+	text-decoration: none;
+
+	opacity: 0;
+	pointer-events: none;
+	transition: opacity 0.6s ease-in-out;
+
+	position: fixed;
+	bottom: 2rem;
+	right: 3rem;
+	
+	i {
+		animation: bounce 1.2s infinite alternate;
+	}
+}
+
+body.is-scrolled-deeply #return-to-top {
+	opacity: 0.75;
+	pointer-events: auto;
+	&:hover {
+		opacity: 1;
+	}
+}
\ No newline at end of file
